<?php
$path = rtrim($_SERVER['DOCUMENT_ROOT'], '/');
include_once $path . '/api/lib/api_common.php';
include_once $path . '/Model_adm.php';

function check_user_rights()
{
	global $user;
	global $dbconnection;
	if($user->getAccess($dbconnection, 'esia_administration') != 1)
	{
		throw new AccessDeniedException("This user doesn't have administration privileges");
	}
}

function run_resource_method()
{
	global $dbconnection;
	global $urlParameters;
	global $method;

	// Ex: /api/rss/channel channel will be the type
	$type = '';
	if(isset($urlParameters[0]))
	{
		$type = $urlParameters[0];
	}

	$action = '';
	if(isset($_REQUEST['action']))
	{
		$action = $_REQUEST['action'];
	}

	try
	{
		if($type == 'channel')
		{
			if($method == 'GET')
			{
				$channel = NULL;
				$type = NULL;
				$userId = NULL;
				$sort = NULL;

				// Get channel by bame, categories or else get all channels
				if(!empty($_GET['name']))
				{
					// Get channel by name
					$channel = trim($_GET['name']);
				}
				elseif(!empty($_GET['categories']))
				{
					// Get channels by categories
					$channel = array();
					$categories = preg_split('/\s*,\s*/', trim($_GET['categories']));
					foreach($categories as $cat)
					{
						$channel = array_merge($channel, Model_esia::getRSSChannelByCategory($dbconnection, $cat));
					}
					if(empty($channel))
					{
						// No channels found for those categories
						return array();
					}
					else
					{
						$channel = array_unique($channel);
					}
				}
				// Other filters
				if(!empty($_GET['type']))
				{
					$type = trim($_GET['type']);
				}
				if(!empty($_GET['user_id']))
				{
					$userId = intval(trim($_GET['user_id']));
				}
				if(!empty($_GET['sort']))
				{
					$sort = strtoupper(trim($_GET['sort']));
				}
				$channels = Model_esia::getRSSChannel($dbconnection, $channel, $type, $userId, $sort);

				return $channels;
			}
			elseif($method == 'POST')
			{
				if($action == 'add')
				{
					// Default values (only name & url are required)
					$channel = array(
						'id' => NULL,
						'name' => '',
						'description' => '',
						'url' => '',
						'lang' => '',
						'enable' => 1,
						'group' => array('RSS_GROUP_ALL'),
						'categories' => array(),
					);
					
					// Check required parameters
					if(empty($_POST['name']) || !is_string($_POST['name']) || empty($_POST['url']))
					{
						throw new Exception('Required channel name & URL.');
					}
					else
					{
						$channel['name'] = $_POST['name'];
						$channel['url'] = filter_var($_POST['url'], FILTER_SANITIZE_URL);
					}
					// Check url
					if(!filter_var($channel['url'], FILTER_VALIDATE_URL))
					{
						throw new Exception('Invalid URL (' . $channel['url'] . ')');
					}

					// Get others parameters
					if(!empty($_POST['description']) && is_string($_POST['description']))
					{
						$channel['description'] = $_POST['description'];
					}
					if(!empty($_POST['lang']) && is_string($_POST['lang']))
					{
						$channel['lang'] = $_POST['lang'];
					}
					if(isset($_POST['enable']) && (strtolower($_POST['enable']) == 'false' || $_POST['enable'] == 0))
					{
						$channel['enable'] = 0;
					}
					if(!empty($_POST['group']))
					{
						// Explode on , with trim of whitespaces
						$channel['group'] = preg_split('/\s*,\s*/', trim($_POST['group']));

						if(in_array('RSS_GROUP_NO', $channel['group']))
						{
							$channel['group'] = NULL;
						}
						elseif(in_array('RSS_GROUP_ALL', $channel['group']))
						{
							$channel['group'] = array('RSS_GROUP_ALL');
						}
						else
						{
							$channel['group'] = array_unique($channel['group']);
						}
					}
					$categoriesIds = array();
					if(!empty($_POST['categories']))
					{
						// Explode on , with trim of whitespaces
						$channel['categories'] = preg_split('/\s*,\s*/', trim($_POST['categories']));
						$channel['categories'] = array_unique($channel['categories']);

						// Get ids of existing categories & if category does not exist create it
						foreach($channel['categories'] as $cat)
						{
							$category = Model_esia::getRSSCategory($dbconnection, $cat);
							if(isset($category[0]['id']))
							{
								// Category exists, save id
								$categoriesIds[] = $category[0]['id'];
							}
							else
							{
								// Category does not exist, create it and save id
								$categoriesIds[] = Model_adm::addRSSCategory($dbconnection, $cat, '');
							}
						}
					}

					// Add channel
					$channel['id'] = Model_adm::addRSSChannel($dbconnection, $channel['name'], $channel['description'], 'REMOTE', $channel['url'], $channel['lang'], '', $channel['enable'], $categoriesIds, $channel['group']);

					// Return channel if succeed or error message
					if(empty($channel['id']))
					{
						throw new Exception('Failed to create channel (' . $channel['name'] . ')');
					}

					return $channel;
				}
			}
		}
	}
	catch(HTTPException $e)
	{
		throw $e;
	}
	catch(Exception $e)
	{
		throw new NotFoundResourceException('Error RSS: ' . $e->getMessage());
	}
}
?>
